def SieveEra(limit=20):
    is_prime = [True] * (limit+1)
    is_prime[0] = is_prime[1] = False
    
    for number in range(2, int(limit**0.5)+1):
        if is_prime[number]:
            for m in range(number**2, limit+1, number):
                is_prime[m] = False
                
    primes = [number for number in range(2, limit+1) if is_prime[number]]
    return primes


from setuptools import setup

with open('README.rst', 'r', encoding='utf-8') as f:
    ln = f.read()

setup(
    name="PySieveEra",
    version="0.1",
    description="Generate a list of prime numbers within a specified range",
    long_description= ln,
    long_description_content_type='text/x-rst',
    license="MIT",
    author="Md. Ismiel Hossen Abir",
    packages=["PySieveEra"],
    url="https://pypi.org/project/PySieveEra/",
    install_requires=[]
    
)